@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
 from google.oauth2.service_account import Credentials
 from typing import Generic
+from maleo.schemas.service import ServiceContext
 from maleo.schemas.settings import ServiceSettingsT
 from maleo.logging.config import Config as LogConfig
 from maleo.logging.logger import ServiceLoggers
@@ -22,6 +23,10 @@ class ServiceManager(ABC, Generic[ServiceSettingsT, ConfigT]):
         self._settings = settings
         self._config = config
 
+        self._service_context = ServiceContext(
+            environment=self._settings.ENVIRONMENT, key=self._settings.SERVICE_KEY
+        )
+
         self._initialize_loggers()
 
     def _initialize_loggers(self) -> None:
